@@ -2,13 +2,13 @@
 
 """This is the main module that contains views and the main logic"""
 
-# Libraries
+# Libraries:
 import curses
 import time
 import getopt
 import sys
 
-# Modules
+# Modules:
 from calcure.calendars import Calendar
 from calcure.configuration import cf
 from calcure.weather import Weather
@@ -16,11 +16,23 @@ from calcure.repository import Importer, FileRepository
 from calcure.dialogues import clear_line
 from calcure.screen import Screen
 from calcure.data import *
-from calcure.translation_en import *
 from calcure.controls import *
 
 
-__version__ = "2.3.1"
+# Language:
+if cf.LANG == "fr":
+    from calcure.translations.fr import *
+elif cf.LANG == "ru":
+    from calcure.translations.ru import *
+elif cf.LANG == "it":
+    from calcure.translations.it import *
+elif cf.LANG == "br":
+    from calcure.translations.br import *
+else:
+    from calcure.translations.en import *
+
+
+__version__ = "2.4.3"
 
 
 def initialize_colors():
@@ -748,6 +760,40 @@ class JournalScreenView(View):
         journal_view.render()
 
 
+class WelcomeScreenView(View):
+    """Welcome screen displaying greeting info on the first run"""
+
+    def __init__(self, stdscr, y, x, screen):
+        super().__init__(stdscr, y, x)
+        self.screen = screen
+
+    def calibrate_position(self):
+        """Depending on the screen space calculate the best position"""
+        self.y_max, self.x_max = self.stdscr.getmaxyx()
+
+    def render(self):
+        """Draw the welcome screen"""
+        self.calibrate_position()
+        curses.halfdelay(255)
+        self.stdscr.clear()
+        self.fill_background()
+
+        if self.x_max < len(MSG_WELCOME_4)+2 or self.y_max < 12:
+            self.display_line(0, 0, "Welcome!", Color.ACTIVE_PANE)
+            return
+
+        d_x = self.x_max//2
+        d_y = self.y_max//2 - 5
+
+        self.display_line(d_y, d_x - len(MSG_WELCOME_1+__version__+" ")//2, f"{MSG_WELCOME_1} {__version__}", Color.ACTIVE_PANE)
+        self.display_line(d_y + 1, d_x - len(MSG_WELCOME_2)//2, MSG_WELCOME_2, Color.TODO)
+        self.display_line(d_y + 3, d_x - len(MSG_WELCOME_3)//2, MSG_WELCOME_3, Color.TODO)
+        self.display_line(d_y + 4, d_x - len(cf.config_folder)//2, cf.config_folder, Color.TITLE)
+        self.display_line(d_y + 6, d_x - len(MSG_WELCOME_4)//2, MSG_WELCOME_4, Color.TODO)
+        self.display_line(d_y + 7, d_x - len(MSG_SITE)//2, MSG_SITE, Color.TITLE)
+        self.display_line(d_y + 9, d_x - len(MSG_WELCOME_5)//2, MSG_WELCOME_5, Color.TODO)
+
+
 class HelpScreenView(View):
     """Help screen displaying information about keybindings"""
 
@@ -820,7 +866,7 @@ def main(stdscr) -> None:
     # Load the data:
     weather = Weather(cf.WEATHER_CITY)
     if cf.SHOW_WEATHER:
-        print("Weather is loading...")
+        print(cf.MSG_WEATHER)
         weather.load_from_wttr()
     screen = Screen(stdscr, cf.PRIVACY_MODE, cf.DEFAULT_VIEW, cf.SPLIT_SCREEN, cf.RIGHT_PANE_PERCENTAGE, cf.USE_PERSIAN_CALENDAR)
     file_repository = FileRepository(cf.TASKS_FILE, cf.EVENTS_FILE, cf.HOLIDAY_COUNTRY, cf.USE_PERSIAN_CALENDAR)
@@ -845,9 +891,16 @@ def main(stdscr) -> None:
     daily_screen_view = DailyScreenView(stdscr, 0, 0, weather, user_events, holidays, birthdays, user_tasks, screen)
     journal_screen_view = JournalScreenView(stdscr, 0, 0, weather, user_tasks, screen)
     help_screen_view = HelpScreenView(stdscr, 0, 0, screen)
+    welcome_screen_view = WelcomeScreenView(stdscr, 0, 0, screen)
     footer_view = FooterView(stdscr, 0, 0, screen)
     separator_view = SeparatorView(stdscr, 0, 0, screen)
 
+    # Show welcome screen on the first run:
+    if cf.is_first_run:
+        screen.state = AppState.WELCOME
+    while screen.state == AppState.WELCOME:
+        welcome_screen_view.render()
+        control_welcome_screen(stdscr, screen)
 
     # Running different screens depending on the state:
     while screen.state != AppState.EXIT:
