@@ -12,15 +12,17 @@ from calcure.data import AppState
 class Config:
     """User configuration loaded from the config.ini file"""
     def __init__(self):
-        self.taskwarrior_folder    = str(pathlib.Path.home()) + "/.task"
-        self.calcurse_todo_file    = str(pathlib.Path.home()) + "/.local/share/calcurse/todo"
-        self.calcurse_events_file  = str(pathlib.Path.home()) + "/.local/share/calcurse/apts"
-        self.config_folder         = str(pathlib.Path.home()) + "/.config/calcure"
-        self.config_file           = self.config_folder + "/config.ini"
+        self.taskwarrior_folder   = str(pathlib.Path.home()) + "/.task"
+        self.calcurse_todo_file   = str(pathlib.Path.home()) + "/.local/share/calcurse/todo"
+        self.calcurse_events_file = str(pathlib.Path.home()) + "/.local/share/calcurse/apts"
+        self.config_folder        = str(pathlib.Path.home()) + "/.config/calcure"
+        self.config_file          = self.config_folder + "/config.ini"
+        self.is_first_run         = True
 
     def create_config_file(self):
         """Create config.ini file if it does not exist"""
         if os.path.exists(self.config_file):
+            self.is_first_run = False
             return
 
         if not os.path.exists(self.config_folder):
@@ -32,6 +34,7 @@ class Config:
                 "calcurse_todo_file":        str(self.calcurse_todo_file),
                 "calcurse_events_file":      str(self.calcurse_events_file),
                 "taskwarrior_folder":        str(self.taskwarrior_folder),
+                "language":                  "en",
                 "default_view":              "calendar",
                 "birthdays_from_abook":      "Yes",
                 "show_keybindings":          "Yes",
@@ -194,6 +197,7 @@ class Config:
             self.SHOW_NOTHING_PLANNED      = conf.getboolean("Parameters", "show_nothing_planned", fallback=True)
             self.SHOW_CALENDAR_BOARDERS    = conf.getboolean("Parameters", "show_calendar_boarders", fallback=False)
             self.USE_PERSIAN_CALENDAR      = conf.getboolean("Parameters", "use_persian_calendar", fallback=False)
+            self.LANG                      = conf.get("Parameters", "language", fallback="en")
             self.START_WEEK_DAY            = int(conf.get("Parameters", "start_week_day", fallback=1))
             self.WEEKEND_DAYS              = conf.get("Parameters", "weekend_days", fallback="6,7")
             self.WEEKEND_DAYS              = [int(i) for i in self.WEEKEND_DAYS.split(",")]
@@ -314,7 +318,7 @@ class Config:
                     self.DEFAULT_VIEW = AppState.HELP
                 elif opt in ('-v'):
                     self.DEFAULT_VIEW = AppState.EXIT
-                    print ('Calcure - version 2.3.1')
+                    print ('Calcure - version 2.4.1')
                 elif opt in ('-i'):
                     self.USE_PERSIAN_CALENDAR = True
         except getopt.GetoptError:
