@@ -2,11 +2,23 @@
 
 import curses
 
+# Modules:
 from calcure.configuration import cf
-from calcure.translation_en import *
 from calcure.data import *
 from calcure.dialogues import *
 
+# Language:
+if cf.LANG == "fr":
+    from calcure.translations.fr import *
+elif cf.LANG == "ru":
+    from calcure.translations.ru import *
+elif cf.LANG == "it":
+    from calcure.translations.it import *
+elif cf.LANG == "br":
+    from calcure.translations.br import *
+else:
+    from calcure.translations.en import *
+
 
 def control_monthly_screen(stdscr, user_events, screen, importer):
     """Handle user input on the daily screen"""
@@ -459,3 +471,24 @@ def control_help_screen(stdscr, screen):
     # Prevent crash if no input:
     except curses.error:
         pass
+
+
+def control_welcome_screen(stdscr, screen):
+    """Process user input on the welcome screen"""
+    try:
+        # Getting user's input:
+        screen.key = stdscr.getkey()
+
+        # Handle key to call help screen:
+        if screen.key in ["?"]:
+            screen.state = AppState.HELP
+        else:
+            screen.state = AppState.CALENDAR
+
+    except KeyboardInterrupt:
+        confirmed = ask_confirmation(stdscr, MSG_EXIT, cf.ASK_CONFIRMATIONS)
+        screen.state = AppState.EXIT if confirmed else screen.state
+
+    # Prevent crash if no input:
+    except curses.error:
+        pass
